@@ -21,10 +21,10 @@
 import os.path
 
 PACKAGE   = "pessulus"
-VERSION   = "2.24.0"
+VERSION   = "2.28.0"
 
 LOCALEDIR = "/usr/local/share/locale"
 DATADIR   = "/usr/local/share"
-GLADEDIR  = "/usr/local/share/pessulus/glade"
+BUILDERDIR  = "/usr/local/share/pessulus/ui"
 
 GCONF_MANDATORY_SOURCE = "xml:merged:/var/db/gconf/gconf.xml.mandatory"
